@@ -24,7 +24,7 @@
 #' Cocitation coupling
 #' 
 #' Two vertices are cocited if there is another vertex citing both of them.
-#' \code{cocitation} siply counts how many types two vertices are cocited. The
+#' \code{cocitation} simply counts how many types two vertices are cocited. The
 #' bibliographic coupling of two vertices is the number of other vertices they
 #' both cite, \code{bibcoupling} calculates this.
 #' 
@@ -61,9 +61,8 @@ cocitation <- function(graph, v=V(graph)) {
     stop("Not a graph object")
   }
   v <- as.igraph.vs(graph, v)
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_cocitation", graph, v-1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_cocitation, graph, v-1)
   if (igraph_opt("add.vertex.names") && is_named(graph)) {
     rownames(res) <- vertex_attr(graph, "name", v)
     colnames(res) <- vertex_attr(graph, "name")
@@ -78,9 +77,8 @@ bibcoupling <- function(graph, v=V(graph)) {
     stop("Not a graph object")
   }
   v <- as.igraph.vs(graph, v)
-  on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  res <- .Call("R_igraph_bibcoupling", graph, v-1,
-               PACKAGE="igraph")
+  on.exit( .Call(C_R_igraph_finalizer) )
+  res <- .Call(C_R_igraph_bibcoupling, graph, v-1)
   if (igraph_opt("add.vertex.names") && is_named(graph)) {
     rownames(res) <- vertex_attr(graph, "name", v)
     colnames(res) <- vertex_attr(graph, "name")
