@@ -92,6 +92,43 @@ sample_seq <- function(low, high, length) {
         as.numeric(length))
 }
 
+#' Common handler for vertex type arguments in igraph functions
+#'
+#' This function takes the \code{types} and \code{graph} arguments from a
+#' public igraph function call and validates the vertex type vector.
+#'
+#' When the provided vertex types are NULL and the graph has a \code{types}
+#' vertex attribute, then the value of this vertex attribute will be used as
+#' vertex types. Non-logical vertex type vectors are coerced into logical
+#' vectors after printing a warning.
+#'
+#' @param types the vertex types
+#' @param graph the graph
+#' @param required whether the graph has to be bipartite
+#' @return A logical vector representing the resolved vertex type for each
+#' vertex in the graph
+#' @author Tamas Nepusz \email{ntamas@gmail.com}
+#' @keywords internal
+#'
+handle_vertex_type_arg <- function(types, graph, required = T) {
+  if (is.null(types) && "type" %in% vertex_attr_names(graph)) { 
+    types <- V(graph)$type 
+  } 
+  if (!is.null(types)) {
+    if (!is.logical(types)) {
+      warning("vertex types converted to logical")
+    }
+    types <- as.logical(types)
+    if (any(is.na(types))) {
+      stop("`NA' is not allowed in vertex types")
+    }
+  }
+  if (is.null(types) && required) {
+    stop("Not a bipartite graph, supply `types' argument") 
+  }
+  return(types)
+}
+
 igraph.match.arg <- function(arg, choices, several.ok=FALSE) {
   if (missing(choices)) {
     formal.args <- formals(sys.function(sys.parent()))
